aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorwmeier <wmeier@f5534014-38df-0310-8fa8-9805f1628bb7>2008-12-17 00:08:38 +0000
committerwmeier <wmeier@f5534014-38df-0310-8fa8-9805f1628bb7>2008-12-17 00:08:38 +0000
commit9ef1a0a24d7401e535322205e3537b7669a7c045 (patch)
tree5a9e06dd5f91951645bff0dd47c3d1bca8623fe8
parent9c3967c861ca0cfed11ad123563598f65b26fb3d (diff)
Fix typos and spelling (mostly in text strings)
git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@27028 f5534014-38df-0310-8fa8-9805f1628bb7
-rwxr-xr-xepan/dissectors/ncp2222.py6
-rw-r--r--epan/dissectors/packet-3com-njack.c2
-rw-r--r--epan/dissectors/packet-9p.c2
-rw-r--r--epan/dissectors/packet-alcap.c8
-rw-r--r--epan/dissectors/packet-app-pkix-cert.c2
-rw-r--r--epan/dissectors/packet-bacapp.c2
-rw-r--r--epan/dissectors/packet-bootp.c2
-rw-r--r--epan/dissectors/packet-bssgp.c2
-rw-r--r--epan/dissectors/packet-bthci_cmd.c4
-rw-r--r--epan/dissectors/packet-cops.c2
-rw-r--r--epan/dissectors/packet-dcerpc-dce122.c2
-rw-r--r--epan/dissectors/packet-dcm.c10
-rw-r--r--epan/dissectors/packet-dec-dnart.c2
-rw-r--r--epan/dissectors/packet-dpnss.c4
-rw-r--r--epan/dissectors/packet-drda.c2
-rw-r--r--epan/dissectors/packet-dtls.c2
-rw-r--r--epan/dissectors/packet-e164.c2
-rw-r--r--epan/dissectors/packet-edonkey.c2
-rw-r--r--epan/dissectors/packet-fcswils.c8
-rw-r--r--epan/dissectors/packet-fmp.c4
-rw-r--r--epan/dissectors/packet-gsm_a_bssmap.c6
-rw-r--r--epan/dissectors/packet-gsm_a_gm.c4
-rw-r--r--epan/dissectors/packet-gsm_bssmap_le.c2
-rw-r--r--epan/dissectors/packet-h248_annex_c.c4
-rw-r--r--epan/dissectors/packet-hsrp.c2
-rw-r--r--epan/dissectors/packet-icep.c2
-rw-r--r--epan/dissectors/packet-ipmi-app.c4
-rw-r--r--epan/dissectors/packet-ipvs-syncd.c2
-rw-r--r--epan/dissectors/packet-ipxwan.c2
-rw-r--r--epan/dissectors/packet-isup.c14
-rw-r--r--epan/dissectors/packet-kerberos.c2
-rw-r--r--epan/dissectors/packet-lldp.c2
-rw-r--r--epan/dissectors/packet-ncp-nmas.c12
-rw-r--r--epan/dissectors/packet-nhrp.c2
-rw-r--r--epan/dissectors/packet-pcep.c26
-rw-r--r--epan/dissectors/packet-pcnfsd.c4
-rw-r--r--epan/dissectors/packet-ppp.c2
-rw-r--r--epan/dissectors/packet-ptp.c2
-rw-r--r--epan/dissectors/packet-rdt.c2
-rw-r--r--epan/dissectors/packet-rtcp.c2
-rw-r--r--epan/dissectors/packet-s5066.c2
-rw-r--r--epan/dissectors/packet-sccpmg.c2
-rw-r--r--epan/dissectors/packet-scsi-mmc.c4
-rw-r--r--epan/dissectors/packet-scsi.c12
-rw-r--r--epan/dissectors/packet-smb.c2
-rw-r--r--epan/dissectors/packet-smpp.c2
-rw-r--r--epan/dissectors/packet-sna.c2
-rw-r--r--epan/dissectors/packet-ssl.c4
-rw-r--r--epan/dissectors/packet-tcp.c4
-rw-r--r--epan/dissectors/packet-ucp.c2
-rw-r--r--epan/dissectors/packet-umts_fp.c12
-rw-r--r--epan/dissectors/packet-user_encap.c2
-rw-r--r--epan/dissectors/packet-wps.c2
-rw-r--r--epan/dissectors/packet-xtp.c2
54 files changed, 111 insertions, 111 deletions
diff --git a/epan/dissectors/ncp2222.py b/epan/dissectors/ncp2222.py
index a27dfc19cd..91a52b7804 100755
--- a/epan/dissectors/ncp2222.py
+++ b/epan/dissectors/ncp2222.py
@@ -3374,7 +3374,7 @@ RemoveOpenRights = bitfield8("remove_open_rights", "Remove Open Rights", [
])
RenameFlag = bitfield8("rename_flag", "Rename Flag", [
bf_boolean8(0x01, "rename_flag_ren", "Rename to Myself allows file to be renamed to it's original name"),
- bf_boolean8(0x02, "rename_flag_comp", "Compatability allows files that are marked read only to be opened with read/write access"),
+ bf_boolean8(0x02, "rename_flag_comp", "Compatibility allows files that are marked read only to be opened with read/write access"),
bf_boolean8(0x04, "rename_flag_no", "Name Only renames only the specified name space entry name"),
])
RepliesCancelled = uint16("replies_cancelled", "Replies Cancelled")
@@ -3547,7 +3547,7 @@ SecretStoreVerb = val_string8("ss_verb", "Secret Store V
])
SecurityEquivalentList = fw_string("security_equiv_list", "Security Equivalent List", 128)
SecurityFlag = bitfield8("security_flag", "Security Flag", [
- bf_boolean8(0x01, "checksuming", "Checksumming"),
+ bf_boolean8(0x01, "checksumming", "Checksumming"),
bf_boolean8(0x02, "signature", "Signature"),
bf_boolean8(0x04, "complete_signatures", "Complete Signatures"),
bf_boolean8(0x08, "encryption", "Encryption"),
@@ -4951,7 +4951,7 @@ PacketBurstInformation = struct("packet_burst_information", [
uint32("write_timeout", "Write Time Out Count"),
uint32("write_got_an_ack0", "Write Got An ACK Count 0"),
uint32("write_got_an_ack1", "Write Got An ACK Count 1"),
- uint32("poll_abort_conn", "Poller Aborted The Connnection Count"),
+ uint32("poll_abort_conn", "Poller Aborted The Connection Count"),
uint32("may_had_out_of_order", "Maybe Had Out Of Order Writes Count"),
uint32("had_an_out_of_order", "Had An Out Of Order Write Count"),
uint32("moved_the_ack_bit_dn", "Moved The ACK Bit Down Count"),
diff --git a/epan/dissectors/packet-3com-njack.c b/epan/dissectors/packet-3com-njack.c
index e5d278a13e..511d5c8605 100644
--- a/epan/dissectors/packet-3com-njack.c
+++ b/epan/dissectors/packet-3com-njack.c
@@ -746,7 +746,7 @@ proto_register_njack(void)
0x0, "", HFILL }},
{ &hf_njack_tlv_countermode,
- { "TlvTypeCountermode", "njack.tlv.contermode", FT_UINT8, BASE_DEC, VALS(&njack_countermode),
+ { "TlvTypeCountermode", "njack.tlv.countermode", FT_UINT8, BASE_DEC, VALS(&njack_countermode),
0x0, "", HFILL }},
{ &hf_njack_tlv_powerforwarding,
diff --git a/epan/dissectors/packet-9p.c b/epan/dissectors/packet-9p.c
index e63bdf1da7..d1a54bec58 100644
--- a/epan/dissectors/packet-9p.c
+++ b/epan/dissectors/packet-9p.c
@@ -231,7 +231,7 @@ static void dissect_9P(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
if(strcmp(mname,"Unknown") == 0) {
if (check_col(pinfo->cinfo, COL_INFO))
- col_add_fstr(pinfo->cinfo, COL_INFO, "9P Data Continuitation(?) (Tag %u)",(guint)ninemsg);
+ col_add_fstr(pinfo->cinfo, COL_INFO, "9P Data Continuation(?) (Tag %u)",(guint)ninemsg);
return;
}
diff --git a/epan/dissectors/packet-alcap.c b/epan/dissectors/packet-alcap.c
index 76dc7b17e2..f11363b363 100644
--- a/epan/dissectors/packet-alcap.c
+++ b/epan/dissectors/packet-alcap.c
@@ -1621,8 +1621,8 @@ proto_register_alcap(void)
{ &hf_alcap_pssiae_pr_type, { "Profile Type", "alcap.pssiae.profile.type", FT_UINT8, BASE_DEC, VALS(audio_profile_type), 0xc0, "I.366.2 Profile Type", HFILL }},
{ &hf_alcap_pssiae_pr_id, { "Profile Id", "alcap.pssiae.profile.id", FT_UINT8, BASE_DEC, NULL, 0, "", HFILL }},
{ &hf_alcap_pssiae_lb, { "Loopback", "alcap.pssiae.lb", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "", HFILL }},
- { &hf_alcap_pssiae_rc, { "Rate Conctrol", "alcap.pssiae.rc", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "", HFILL }},
- { &hf_alcap_pssiae_syn, { "Syncronization", "alcap.pssiae.syn", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "Transport of synchronization of change in SSCS operation", HFILL }},
+ { &hf_alcap_pssiae_rc, { "Rate Control", "alcap.pssiae.rc", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "", HFILL }},
+ { &hf_alcap_pssiae_syn, { "Synchronization", "alcap.pssiae.syn", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "Transport of synchronization of change in SSCS operation", HFILL }},
{ &hf_alcap_pssiae_frm, { "Frame Mode", "alcap.pssiae.frm", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0x80, "", HFILL }},
{ &hf_alcap_pssiae_cmd, { "Circuit Mode", "alcap.pssiae.cmd", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0x40, "", HFILL }},
{ &hf_alcap_pssiae_mfr2, { "Multi-Frequency R2", "alcap.pssiae.mfr2", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0x20, "", HFILL }},
@@ -1645,8 +1645,8 @@ proto_register_alcap(void)
{ &hf_alcap_ssiae_pr_type, { "Profile Type", "alcap.ssiae.profile.type", FT_UINT8, BASE_DEC, VALS(audio_profile_type), 0xc0, "I.366.2 Profile Type", HFILL }},
{ &hf_alcap_ssiae_lb, { "Loopback", "alcap.ssiae.lb", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "", HFILL }},
- { &hf_alcap_ssiae_rc, { "Rate Conctrol", "alcap.ssiae.rc", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "", HFILL }},
- { &hf_alcap_ssiae_syn, { "Syncronization", "alcap.ssiae.syn", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "Transport of synchronization of change in SSCS operation", HFILL }},
+ { &hf_alcap_ssiae_rc, { "Rate Control", "alcap.ssiae.rc", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "", HFILL }},
+ { &hf_alcap_ssiae_syn, { "Synchronization", "alcap.ssiae.syn", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0xc0, "Transport of synchronization of change in SSCS operation", HFILL }},
{ &hf_alcap_ssiae_pr_id, { "Profile Id", "alcap.ssiae.profile.id", FT_UINT8, BASE_DEC, NULL, 0, "", HFILL }},
{ &hf_alcap_ssiae_frm, { "Frame Mode", "alcap.ssiae.frm", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0x80, "", HFILL }},
{ &hf_alcap_ssiae_cmd, { "Circuit Mode", "alcap.ssiae.cmd", FT_UINT8, BASE_DEC, VALS(enabled_disabled), 0x40, "", HFILL }},
diff --git a/epan/dissectors/packet-app-pkix-cert.c b/epan/dissectors/packet-app-pkix-cert.c
index 8c3aab0d51..dcfee1501e 100644
--- a/epan/dissectors/packet-app-pkix-cert.c
+++ b/epan/dissectors/packet-app-pkix-cert.c
@@ -86,7 +86,7 @@ proto_register_cert(void)
*/
static hf_register_info hf[] = {
{ &hf_cert,
- { "Certififcate", "cert", FT_NONE, BASE_HEX, NULL, 0x00, "Certificate", HFILL}},
+ { "Certificate", "cert", FT_NONE, BASE_HEX, NULL, 0x00, "Certificate", HFILL}},
};
/* Setup protocol subtree array */
diff --git a/epan/dissectors/packet-bacapp.c b/epan/dissectors/packet-bacapp.c
index 7647a88484..b2271f8732 100644
--- a/epan/dissectors/packet-bacapp.c
+++ b/epan/dissectors/packet-bacapp.c
@@ -437,7 +437,7 @@ BACnetEngineeringUnits [] = {
{35,"Watts Per Sq meter"},
{36,"Lumens"},
{37,"Lux"},
- {38,"Foot Candels"},
+ {38,"Foot Candles"},
{39,"Kilograms"},
{40,"Pounds Mass"},
{41,"Tons"},
diff --git a/epan/dissectors/packet-bootp.c b/epan/dissectors/packet-bootp.c
index 8074644e7e..c91b4a40a4 100644
--- a/epan/dissectors/packet-bootp.c
+++ b/epan/dissectors/packet-bootp.c
@@ -587,7 +587,7 @@ static struct opt_info bootp_opt[] = {
/* 107 */ { "Removed/unassigned", opaque, NULL },
/* 108 */ { "Swap Path Option", opaque, NULL },
/* 109 */ { "Unassigned", opaque, NULL },
-/* 110 */ { "IPX Compability", opaque, NULL },
+/* 110 */ { "IPX Compatibility", opaque, NULL },
/* 111 */ { "Unassigned", opaque, NULL },
/* 112 */ { "NetInfo Parent Server Address", ipv4_list, NULL },
/* 113 */ { "NetInfo Parent Server Tag", string, NULL },
diff --git a/epan/dissectors/packet-bssgp.c b/epan/dissectors/packet-bssgp.c
index 78207c46e9..e4b282d58a 100644
--- a/epan/dissectors/packet-bssgp.c
+++ b/epan/dissectors/packet-bssgp.c
@@ -3645,7 +3645,7 @@ decode_iei_requested_gps_assistance_data(bssgp_ie_t *ie, build_info_t *bi, int i
value = get_masked_guint8(data, MASK_H);
pi = proto_tree_add_bitfield8(tf, bi->tvb, bi->offset, MASK_H);
- proto_item_append_text(pi, "H: Acquisition Asssistance is%s requested",
+ proto_item_append_text(pi, "H: Acquisition Assistance is%s requested",
value == 0 ? " not" : "");
bi->offset++;
diff --git a/epan/dissectors/packet-bthci_cmd.c b/epan/dissectors/packet-bthci_cmd.c
index 755fa8a3bb..6d717b040f 100644
--- a/epan/dissectors/packet-bthci_cmd.c
+++ b/epan/dissectors/packet-bthci_cmd.c
@@ -570,9 +570,9 @@ const value_string bthci_cmd_oob_data_present_vals[] = {
const value_string bthci_cmd_auth_req_vals[] = {
{0x00, "MITM Protection Not Required - Single Profile. Numeric Comparison, Automatic Accept Allowed" },
- {0x01, "MITM Protection Required - Single Profile. Use IO Capabilty To Determine Procedure" },
+ {0x01, "MITM Protection Required - Single Profile. Use IO Capability To Determine Procedure" },
{0x02, "MITM Protection Not Required - All Profiles. Numeric Comparison, Automatic Accept Allowed" },
- {0x03, "MITM Protection Required - All Profiles. Use IO Capabilty To Determine Procedure" },
+ {0x03, "MITM Protection Required - All Profiles. Use IO Capability To Determine Procedure" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-cops.c b/epan/dissectors/packet-cops.c
index d29c58ceac..e6ca6e5f26 100644
--- a/epan/dissectors/packet-cops.c
+++ b/epan/dissectors/packet-cops.c
@@ -2126,7 +2126,7 @@ void proto_register_cops(void)
{ &hf_cops_pcmm_classifier_dscp_tos_mask,
{ "DSCP/TOS Mask", "cops.pc_mm_classifier_dscp_mask",
FT_UINT8, BASE_HEX, NULL, 0,
- "PacketCable Multimedia Classifer DSCP/TOS Mask", HFILL }
+ "PacketCable Multimedia Classifier DSCP/TOS Mask", HFILL }
},
{ &hf_cops_pcmm_classifier_src_addr,
{ "Source address", "cops.pc_mm_classifier_src_addr",
diff --git a/epan/dissectors/packet-dcerpc-dce122.c b/epan/dissectors/packet-dcerpc-dce122.c
index 2ae8157d46..ee6804dba9 100644
--- a/epan/dissectors/packet-dcerpc-dce122.c
+++ b/epan/dissectors/packet-dcerpc-dce122.c
@@ -1274,7 +1274,7 @@ const value_string dce_error_vals[] = {
{ 701087993, "CM read starting prefetch for offset .d" },
{ 701087994, "CM swapping out vol structure at .x" },
{ 701087995, "CM async grant RPC vp .x type .#x range(.d:.d)" },
-{ 701087996, "CM asycn grant returns code .d" },
+{ 701087996, "CM async grant returns code .d" },
{ 701087997, "CM async can't find fid's server" },
{ 701087998, "CM async done, states .#x, code .d" },
{ 701087999, "CM TKN_AsyncGrant fid .x..x..x..x, rights .#x" },
diff --git a/epan/dissectors/packet-dec-dnart.c b/epan/dissectors/packet-dec-dnart.c
index ae7a219255..a311821123 100644
--- a/epan/dissectors/packet-dec-dnart.c
+++ b/epan/dissectors/packet-dec-dnart.c
@@ -261,7 +261,7 @@ static const value_string rt_disc_reason_vals[] = {
{ 0, "no error"},
{ 3, "The node is shutting down"},
{ 4, "The destination end user does not exist"},
- { 5, "A conect message contains an invalid end user name"},
+ { 5, "A connect message contains an invalid end user name"},
{ 6, "Destination end user has insufficient resources"},
{ 7, "Unspecified error"},
{ 8, "A third party has disconnected the link"},
diff --git a/epan/dissectors/packet-dpnss.c b/epan/dissectors/packet-dpnss.c
index 1b7d7c1bd8..dd8ebc2ba4 100644
--- a/epan/dissectors/packet-dpnss.c
+++ b/epan/dissectors/packet-dpnss.c
@@ -821,9 +821,9 @@ static const value_string dpnss_sup_serv_par_str_vals[] = {
{ DPNSS_ROUTE_RES_CLASS, "Route Restriction Class"},
{ DPNSS_CBR_GRP, "Call Barring Group"},
{ DPNSS_FAC_LST_CODE, "Facility list code"},
- { DPNSS_NO_OF_FUR_TRANS, "Number of Furhter Transits"},
+ { DPNSS_NO_OF_FUR_TRANS, "Number of Further Transits"},
{ DPNSS_NO_OF_FUR_ALT_R, "Number of Further Alternative routes"},
- { DPNSS_INT_CAP_LEV, "Intrution Cspability level"},
+ { DPNSS_INT_CAP_LEV, "Intrusion Capability level"},
{ DPNSS_NESTING_LEVEL, "Nesting level"},
{ DPNSS_C_PARTY_ADDR, "C Party Address"},
{ DPNSS_B_PARTY_ADDR, "B Party Address"},
diff --git a/epan/dissectors/packet-drda.c b/epan/dissectors/packet-drda.c
index 2e23b950c4..9dc0e63c5e 100644
--- a/epan/dissectors/packet-drda.c
+++ b/epan/dissectors/packet-drda.c
@@ -835,7 +835,7 @@ proto_register_drda(void)
{ "Chained", "drda.ddm.fmt.bit1", FT_BOOLEAN, 4, TFS(&flags_set_truth), DRDA_DSSFMT_CHAINED, "DSSFMT chained", HFILL }},
{ &hf_drda_ddm_fmt_errcont,
- { "Continue", "drda.ddm.fmt.bit2", FT_BOOLEAN, 4, TFS(&flags_set_truth), DRDA_DSSFMT_CONTINUE, "DSSFMT contine on error", HFILL }},
+ { "Continue", "drda.ddm.fmt.bit2", FT_BOOLEAN, 4, TFS(&flags_set_truth), DRDA_DSSFMT_CONTINUE, "DSSFMT continue on error", HFILL }},
{ &hf_drda_ddm_fmt_samecorr,
{ "Same correlation", "drda.ddm.fmt.bit3", FT_BOOLEAN, 4, TFS(&flags_set_truth), DRDA_DSSFMT_SAME_CORR, "DSSFMT same correlation", HFILL }},
diff --git a/epan/dissectors/packet-dtls.c b/epan/dissectors/packet-dtls.c
index b2199b19a5..a05947e9e1 100644
--- a/epan/dissectors/packet-dtls.c
+++ b/epan/dissectors/packet-dtls.c
@@ -390,7 +390,7 @@ dissect_dtls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
conv_version= & ssl_session->version;
/* try decryption only the first time we see this packet
- * (to keep cipher syncronized)and only if we have
+ * (to keep cipher synchronized)and only if we have
* the server private key*/
if (!ssl_session->private_key || pinfo->fd->flags.visited)
ssl_session = NULL;
diff --git a/epan/dissectors/packet-e164.c b/epan/dissectors/packet-e164.c
index b3764e4a76..5bb1b98943 100644
--- a/epan/dissectors/packet-e164.c
+++ b/epan/dissectors/packet-e164.c
@@ -154,7 +154,7 @@ const value_string E164_country_code_value[] = {
{ 0x0385,"Croatia"},
{ 0x0386,"Slovenia"},
{ 0x0387,"Bosnia and Herzegovina"},
- { 0x0388,"Groups of contries:"},
+ { 0x0388,"Groups of countries:"},
{ 0x0389,"Macedonia"},
{ 0x039,"Italy"},
{ 0x040,"Romania"},
diff --git a/epan/dissectors/packet-edonkey.c b/epan/dissectors/packet-edonkey.c
index ccdee822ba..9e65c743fc 100644
--- a/epan/dissectors/packet-edonkey.c
+++ b/epan/dissectors/packet-edonkey.c
@@ -3305,7 +3305,7 @@ void proto_register_edonkey(void) {
{"Source", "edonkey.source",
FT_NONE, BASE_NONE, NULL, 0, "eDonkey File Source", HFILL } },
{ &hf_emule_source_count,
- { "Compeleted Sources Count", "edonkey.emule.source_count",
+ { "Completed Sources Count", "edonkey.emule.source_count",
FT_UINT16, BASE_DEC, NULL, 0, "eMule Completed Sources Count", HFILL } },
{ &hf_emule_zlib,
{ "Compressed Data", "edonkey.emule.zlib",
diff --git a/epan/dissectors/packet-fcswils.c b/epan/dissectors/packet-fcswils.c
index 42715976dd..c9584e9c98 100644
--- a/epan/dissectors/packet-fcswils.c
+++ b/epan/dissectors/packet-fcswils.c
@@ -1995,16 +1995,16 @@ proto_register_fcswils (void)
{"B2B Credit", "swils.elp.b2b", FT_UINT32, BASE_DEC, NULL, 0x0, "",
HFILL}},
{ &hf_swils_elp_compat1,
- {"Compatability Param 1", "swils.elp.compat1", FT_UINT32, BASE_DEC, NULL,
+ {"Compatibility Param 1", "swils.elp.compat1", FT_UINT32, BASE_DEC, NULL,
0x0, "", HFILL}},
{ &hf_swils_elp_compat2,
- {"Compatability Param 2", "swils.elp.compat2", FT_UINT32, BASE_DEC, NULL,
+ {"Compatibility Param 2", "swils.elp.compat2", FT_UINT32, BASE_DEC, NULL,
0x0, "", HFILL}},
{ &hf_swils_elp_compat3,
- {"Compatability Param 3", "swils.elp.compat3", FT_UINT32, BASE_DEC, NULL,
+ {"Compatibility Param 3", "swils.elp.compat3", FT_UINT32, BASE_DEC, NULL,
0x0, "", HFILL}},
{ &hf_swils_elp_compat4,
- {"Compatability Param 4", "swils.elp.compat4", FT_UINT32, BASE_DEC, NULL,
+ {"Compatibility Param 4", "swils.elp.compat4", FT_UINT32, BASE_DEC, NULL,
0x0, "", HFILL}},
{ &hf_swils_efp_rec_type,
{"Record Type", "swils.efp.rectype", FT_UINT8, BASE_HEX,
diff --git a/epan/dissectors/packet-fmp.c b/epan/dissectors/packet-fmp.c
index ce8bd2ae86..a4977f7fbc 100644
--- a/epan/dissectors/packet-fmp.c
+++ b/epan/dissectors/packet-fmp.c
@@ -1126,7 +1126,7 @@ dissect_fmp_attrs(tvbuff_t *tvb, int offset, proto_tree *tree)
proto_tree *attrsTree;
attrstree = proto_tree_add_text(tree, tvb, offset, 84,
- "Attribut: ");
+ "Attribute: ");
attrsTree = proto_item_add_subtree(attrstree,
ett_attrs );
attrs = tvb_get_ntohl(tvb, offset);
@@ -2139,7 +2139,7 @@ proto_register_fmp(void)
NULL, 0, "Signature DATA", HFILL }},
{ &hf_fmp_mount_path, {
"Native Protocol: PATH", "fmp.mount_path", FT_STRING, BASE_NONE,
- NULL, 0, "Absoulte path from the root on the server side", HFILL }},
+ NULL, 0, "Absolute path from the root on the server side", HFILL }},
{ &hf_fmp_sig_offset, {
"Sig Offset", "fmp.dsi.ds.sig_offset", FT_UINT64, BASE_DEC,
NULL, 0, "Sig Offset", HFILL }},
diff --git a/epan/dissectors/packet-gsm_a_bssmap.c b/epan/dissectors/packet-gsm_a_bssmap.c
index ca0a47fbac..3ea06e0262 100644
--- a/epan/dissectors/packet-gsm_a_bssmap.c
+++ b/epan/dissectors/packet-gsm_a_bssmap.c
@@ -344,7 +344,7 @@ static const value_string bssmap_positioning_methods_usage[] = {
static const value_string bssmap_location_information_vals[] = {
{ 0, "current geographic location" },
{ 1, "location assistance information for the target MS" },
- { 2, "deciphering keys for braodcast assistance data for the target MS" },
+ { 2, "deciphering keys for broadcast assistance data for the target MS" },
{ 0, NULL}
};
@@ -3254,8 +3254,8 @@ be_aoip_trans_lay_add(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len
curr_offset+=16;
break;
default:
- /* Bougus */
- proto_tree_add_text(tree, tvb, curr_offset, len, "Bougus length %u",len);
+ /* Bogus */
+ proto_tree_add_text(tree, tvb, curr_offset, len, "Bogus length %u",len);
return(len);
}
proto_tree_add_item(tree, hf_gsm_a_bssmap_aoip_trans_port, tvb, curr_offset, 2, FALSE);
diff --git a/epan/dissectors/packet-gsm_a_gm.c b/epan/dissectors/packet-gsm_a_gm.c
index 8c35235bcc..d5a5b43dcf 100644
--- a/epan/dissectors/packet-gsm_a_gm.c
+++ b/epan/dissectors/packet-gsm_a_gm.c
@@ -4056,7 +4056,7 @@ de_sm_cause(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len _U_, gcha
case 0x1a: str="Insufficient resources"; break;
case 0x1b: str="Missing or unknown APN"; break;
case 0x1c: str="Unknown PDP address or PDP type"; break;
- case 0x1d: str="User Aauthentication failed"; break;
+ case 0x1d: str="User Authentication failed"; break;
case 0x1e: str="Activation rejected by GGSN"; break;
case 0x1f: str="Activation rejected, unspecified"; break;
case 0x20: str="Service option not supported"; break;
@@ -4467,7 +4467,7 @@ de_sm_tflow_temp(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gch
* bit is set to 1; otherwise, the E bit is set to 0.
*/
if (e_bit == 1){
- proto_tree_add_text(tf_tree, tvb, curr_offset, 1, "Note: Possible Authorizaton Token/Flow Identifier not decoded yet");
+ proto_tree_add_text(tf_tree, tvb, curr_offset, 1, "Note: Possible Authorization Token/Flow Identifier not decoded yet");
}
return(curr_offset - offset);
}
diff --git a/epan/dissectors/packet-gsm_bssmap_le.c b/epan/dissectors/packet-gsm_bssmap_le.c
index cb9603d0ea..071f48a0ca 100644
--- a/epan/dissectors/packet-gsm_bssmap_le.c
+++ b/epan/dissectors/packet-gsm_bssmap_le.c
@@ -116,7 +116,7 @@ const value_string gsm_bssmap_le_elem_strings[] = {
{ BSSMAP_LE_LCS_CLIENT_TYPE, "LCS Client Type" },
{ BSSMAP_LE_APDU, "APDU" },
{ BSSMAP_LE_NETWORK_ELEMENT_IDENTITY, "Network Element Identity" },
- { BSSMAP_LE_REQUESTED_GPS_ASSISTANCE_DATA, "Requested GPS Assitance Data" },
+ { BSSMAP_LE_REQUESTED_GPS_ASSISTANCE_DATA, "Requested GPS Assistance Data" },
{ BSSMAP_LE_REQUESTED_GANSS_ASSISTANCE_DATA, "Requested GANSS Assistance Data" },
{ BSSMAP_LE_DECIPHERING_KEYS, "Deciphering Keys" },
{ BSSMAP_LE_RETURN_ERROR_REQUEST, "Return Error Request" },
diff --git a/epan/dissectors/packet-h248_annex_c.c b/epan/dissectors/packet-h248_annex_c.c
index 17cd408b58..3a2f18cb4d 100644
--- a/epan/dissectors/packet-h248_annex_c.c
+++ b/epan/dissectors/packet-h248_annex_c.c
@@ -296,7 +296,7 @@ static const value_string h248_annexc_package_properties_vals[] = {
{ 0xB007, "SDP_P (phone number)" },
{ 0xB008, "SDP_C (connection)" },
{ 0xB009, "SDP_B (bandwidth info)" },
- { 0xB00A, "SDP_Z (TZ adjustement)" },
+ { 0xB00A, "SDP_Z (TZ adjustment)" },
{ 0xB00B, "SDP_K (encryption key)" },
{ 0xB00C, "SDP_A (Session attributes)" },
{ 0xB00D, "SDP_T (Active Session Time)" },
@@ -611,7 +611,7 @@ static const value_string h248_pkg_annexc_addlayer3prot_values[] = {
static const value_string h248_pkg_annexc_nci_satellite_values[] _U_ = {
{0x0,"no satellite circuit"},
{0x1,"one satellite circuit"},
- {0x2,"two satellite circiuts"},
+ {0x2,"two satellite circuits"},
{0x3,"spare"},
{0,NULL}
};
diff --git a/epan/dissectors/packet-hsrp.c b/epan/dissectors/packet-hsrp.c
index a6bf8beb85..3b558391a9 100644
--- a/epan/dissectors/packet-hsrp.c
+++ b/epan/dissectors/packet-hsrp.c
@@ -783,7 +783,7 @@ void proto_register_hsrp(void)
{ &hf_hsrp2_passive_group,
{ "Passive Groups", "hsrp2.passive_groups",
FT_UINT16, BASE_DEC, NULL, 0x0,
- "Standby group number which doesn't become the acitve router myself", HFILL }},
+ "Standby group number which doesn't become the active router myself", HFILL }},
{ &hf_hsrp2_md5_algorithm,
{ "MD5 Algorithm", "hsrp2._md5_algorithm",
diff --git a/epan/dissectors/packet-icep.c b/epan/dissectors/packet-icep.c
index f815d88696..832121634b 100644
--- a/epan/dissectors/packet-icep.c
+++ b/epan/dissectors/packet-icep.c
@@ -1135,7 +1135,7 @@ static void dissect_icep_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
if (tree) {
- DBG0("got an icep msg, start analisys\n");
+ DBG0("got an icep msg, start analysis\n");
/* create display subtree for the protocol */
diff --git a/epan/dissectors/packet-ipmi-app.c b/epan/dissectors/packet-ipmi-app.c
index 589b36bb32..1baada3959 100644
--- a/epan/dissectors/packet-ipmi-app.c
+++ b/epan/dissectors/packet-ipmi-app.c
@@ -1086,7 +1086,7 @@ ipmi_register_app(gint proto_ipmi)
{ "Product ID",
"ipmi.app01.product", FT_UINT16, BASE_HEX, NULL, 0, "", HFILL }},
{ &hf_ipmi_app_01_fw_aux,
- { "Auxillary Firmware Revision Information",
+ { "Auxiliary Firmware Revision Information",
"ipmi.app01.fw.aux", FT_BYTES, BASE_HEX, NULL, 0, "", HFILL }},
{ &hf_ipmi_app_04_result,
@@ -1391,7 +1391,7 @@ ipmi_register_app(gint proto_ipmi)
{ "OEM ID",
"ipmi.app38.rs_oem_iana", FT_UINT24, BASE_DEC, NULL, 0, "", HFILL }},
{ &hf_ipmi_app_38_rs_oem_aux,
- { "OEM Auxillary data",
+ { "OEM Auxiliary data",
"ipmi.app38.rs_oem_aux", FT_UINT8, BASE_HEX, NULL, 0, "", HFILL }},
{ &hf_ipmi_app_39_authtype,
diff --git a/epan/dissectors/packet-ipvs-syncd.c b/epan/dissectors/packet-ipvs-syncd.c
index 7468db30c5..c708c72741 100644
--- a/epan/dissectors/packet-ipvs-syncd.c
+++ b/epan/dissectors/packet-ipvs-syncd.c
@@ -253,7 +253,7 @@ proto_register_ipvs_syncd(void)
{ &hf_syncid,
{ "Synchronization ID", "ipvs.syncid", FT_UINT8, BASE_DEC,
- NULL, 0, "Syncronization ID", HFILL }},
+ NULL, 0, "Synchronization ID", HFILL }},
{ &hf_size,
{ "Size", "ipvs.size", FT_UINT16, BASE_DEC,
diff --git a/epan/dissectors/packet-ipxwan.c b/epan/dissectors/packet-ipxwan.c
index c375332004..3871570bd9 100644
--- a/epan/dissectors/packet-ipxwan.c
+++ b/epan/dissectors/packet-ipxwan.c
@@ -98,7 +98,7 @@ static const value_string ipxwan_option_num_vals[] = {
static const value_string ipxwan_accept_option_vals[] = {
{ 0, "No" },
{ 1, "Yes" },
- { 3, "Not Appplicable" },
+ { 3, "Not Applicable" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-kerberos.c b/epan/dissectors/packet-kerberos.c
index 92ca6c6772..303083e7ad 100644
--- a/epan/dissectors/packet-kerberos.c
+++ b/epan/dissectors/packet-kerberos.c
@@ -3251,7 +3251,7 @@ dissect_krb5_authenticator_vno(proto_tree *tree, tvbuff_t *tvb, int offset, asn1
#define KRB5_GSS_C_INTEG_FLAG 0x20
#define KRB5_GSS_C_DCE_STYLE 0x1000
static const true_false_string tfs_gss_flags_deleg = {
- "Delegate credantials to remote peer",
+ "Delegate credentials to remote peer",
"Do NOT delegate"
};
static const true_false_string tfs_gss_flags_mutual = {
diff --git a/epan/dissectors/packet-lldp.c b/epan/dissectors/packet-lldp.c
index 91c94956f4..aa199db20c 100644
--- a/epan/dissectors/packet-lldp.c
+++ b/epan/dissectors/packet-lldp.c
@@ -1635,7 +1635,7 @@ dissect_media_tlv(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, guint
}
tempByte = tvb_get_guint8(tvb, tempOffset);
if (tree)
- proto_tree_add_text(tree, tvb, tempOffset, 1, "Applicaton Type: %s (%u)",
+ proto_tree_add_text(tree, tvb, tempOffset, 1, "Application Type: %s (%u)",
val_to_str(tempByte, media_application_type, "Unknown"), tempByte);
tempOffset++;
tlvLen--;
diff --git a/epan/dissectors/packet-ncp-nmas.c b/epan/dissectors/packet-ncp-nmas.c
index 56af654986..7ec499fb0b 100644
--- a/epan/dissectors/packet-ncp-nmas.c
+++ b/epan/dissectors/packet-ncp-nmas.c
@@ -52,7 +52,7 @@ static int hf_msg_version = -1;
static int hf_session_ident = -1;
static int hf_msg_verb = -1;
static int hf_attribute = -1;
-static int hf_clearence = -1;
+static int hf_clearance = -1;
static int hf_login_sequence = -1;
static int hf_opaque = -1;
static int hf_data = -1;
@@ -100,7 +100,7 @@ static const value_string nmas_msgverb_enum[] = {
static const value_string nmas_attribute_enum[] = {
{ 1, "User Name" },
{ 2, "Tree Name" },
- { 4, "Clearence" },
+ { 4, "Clearance" },
{ 11, "Login Sequence" },
{ 0, NULL }
};
@@ -439,7 +439,7 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
foffset = nmas_string(tvb, hf_tree, atree, foffset, FALSE);
break;
case 4:
- foffset = nmas_string(tvb, hf_clearence, atree, foffset, FALSE);
+ foffset = nmas_string(tvb, hf_clearance, atree, foffset, FALSE);
break;
case 11:
foffset = nmas_string(tvb, hf_login_sequence, atree, foffset, FALSE);
@@ -719,10 +719,10 @@ proto_register_nmas(void)
{ "Attribute Type", "nmas.attribute", FT_UINT32, BASE_DEC, VALS(nmas_attribute_enum), 0x0,
"Attribute Type", HFILL }},
- { &hf_clearence,
- { "Requested Clearence", "nmas.clearence",
+ { &hf_clearance,
+ { "Requested Clearance", "nmas.clearance",
FT_STRING, BASE_NONE, NULL, 0x0,
- "Requested Clearence", HFILL }},
+ "Requested Clearance", HFILL }},
{ &hf_login_sequence,
{ "Requested Login Sequence", "nmas.login_seq",
diff --git a/epan/dissectors/packet-nhrp.c b/epan/dissectors/packet-nhrp.c
index 69dfca849b..421cd0c902 100644
--- a/epan/dissectors/packet-nhrp.c
+++ b/epan/dissectors/packet-nhrp.c
@@ -746,7 +746,7 @@ proto_register_nhrp(void)
{ "Client Protocol Address", "nhrp.client.prot.addr", FT_IPv4, BASE_NONE, NULL, 0x0, "", HFILL }},
{ &hf_nhrp_ext_C,
- { "Compulsary Flag", "nhrp.ext.c", FT_BOOLEAN, 16, NULL, 0x8000, "", HFILL }},
+ { "Compulsory Flag", "nhrp.ext.c", FT_BOOLEAN, 16, NULL, 0x8000, "", HFILL }},
{ &hf_nhrp_ext_type,
{ "Extension Type", "nhrp.ext.type", FT_UINT16, BASE_HEX, NULL, 0x3FFF, "", HFILL }},
{ &hf_nhrp_ext_len,
diff --git a/epan/dissectors/packet-pcep.c b/epan/dissectors/packet-pcep.c
index c907f9fa1b..a0dc1e08ee 100644
--- a/epan/dissectors/packet-pcep.c
+++ b/epan/dissectors/packet-pcep.c
@@ -389,10 +389,10 @@ static const value_string pcep_close_reason_obj_vals[] = {
{0, NULL }
};
-static const value_string pcep_xro_atribute_obj_vals[] = {
- {ATTR_INTERFACE, "Atribute = 0 Interface" },
- {ATTR_NODE, "Atribute = 1 Node " },
- {ATTR_SRLG, "Atribute = 2 SRLG" },
+static const value_string pcep_xro_attribute_obj_vals[] = {
+ {ATTR_INTERFACE, "Attribute = 0 Interface" },
+ {ATTR_NODE, "Attribute = 1 Node " },
+ {ATTR_SRLG, "Attribute = 2 SRLG" },
{0, NULL }
};
@@ -439,7 +439,7 @@ enum pcep_filter_keys{
PCEPF_SUBOBJ_SRLG,
PCEPF_SUBOBJ_EXRS,
PCEPF_SUBOBJ_XRO,
- PCEPF_SUB_XRO_ATRIB,
+ PCEPF_SUB_XRO_ATTRIB,
PCEPF_MAX
};
@@ -644,7 +644,7 @@ static hf_register_info pcepf_info[] = {
{ "SUBOBJECT: Unnumbered Interface ID", "pcep.subobj.unnum.interfaceid", FT_NONE, BASE_NONE, NULL, 0x0,
"", HFILL }},
{&pcep_filter[PCEPF_SUBOBJ_AUTONOMOUS_SYS_NUM],
- { "SUBOBJECT: Autonomous System Number", "pcep.subobj.auntonomus.sys.num", FT_NONE, BASE_NONE, NULL, 0x0,
+ { "SUBOBJECT: Autonomous System Number", "pcep.subobj.autonomous.sys.num", FT_NONE, BASE_NONE, NULL, 0x0,
"", HFILL }},
{&pcep_filter[PCEPF_SUBOBJ_SRLG],
{ "SUBOBJECT: SRLG", "pcep.subobj.srlg", FT_NONE, BASE_NONE, NULL, 0x0,
@@ -658,8 +658,8 @@ static hf_register_info pcepf_info[] = {
{&pcep_xro_flags_f,
{ "Fail (F)", "pcep.xro.flags.f", FT_BOOLEAN, 16, TFS(&tfs_set_notset), PCEP_XRO_F,
"", HFILL }},
- {&pcep_filter[PCEPF_SUB_XRO_ATRIB],
- { "Attribute", "pcep.xro.sub.atribute", FT_UINT32, BASE_DEC, VALS(pcep_xro_atribute_obj_vals), 0x0,
+ {&pcep_filter[PCEPF_SUB_XRO_ATTRIB],
+ { "Attribute", "pcep.xro.sub.attribute", FT_UINT32, BASE_DEC, VALS(pcep_xro_attribute_obj_vals), 0x0,
"", HFILL }},
{&pcep_subobj_flags_lpa,
@@ -769,7 +769,7 @@ dissect_subobj_ipv4(proto_tree *pcep_subobj_tree, tvbuff_t *tvb, int offset, int
proto_tree_add_text(pcep_subobj_ipv4, tvb, offset+1, 1, "Length: %u", length);
proto_tree_add_text(pcep_subobj_ipv4, tvb, offset+2, 4, "IPv4 Address: (%s)", ip_to_str(tvb_get_ptr(tvb, offset+2, 4)));
proto_tree_add_text(pcep_subobj_ipv4, tvb, offset+6, 1, "Prefix Length: %u", prefix_length);
- proto_tree_add_text(pcep_subobj_ipv4, tvb, offset+7, 1, "%s",val_to_str(resvd, pcep_xro_atribute_obj_vals, "Unknown Atribute (%u). "));
+ proto_tree_add_text(pcep_subobj_ipv4, tvb, offset+7, 1, "%s",val_to_str(resvd, pcep_xro_attribute_obj_vals, "Unknown Attribute (%u). "));
break;
default:
@@ -836,7 +836,7 @@ dissect_subobj_ipv6(proto_tree *pcep_subobj_tree, tvbuff_t *tvb, int offset, int
proto_tree_add_text(pcep_subobj_ipv6, tvb, offset+1, 1, "Length: %u", length);
proto_tree_add_text(pcep_subobj_ipv6, tvb, offset+2, 16, "IPv6 Address: %s", ip6_to_str((const struct e_in6_addr *)tvb_get_ptr(tvb, offset+2, 16)));
proto_tree_add_text(pcep_subobj_ipv6, tvb, offset+18, 1, "Prefix Length: %u", prefix_length);
- proto_tree_add_text(pcep_subobj_ipv6, tvb, offset+19, 1, "%s", val_to_str(resv, pcep_xro_atribute_obj_vals, "Unknown Atribute (%u). "));
+ proto_tree_add_text(pcep_subobj_ipv6, tvb, offset+19, 1, "%s", val_to_str(resv, pcep_xro_attribute_obj_vals, "Unknown Attribute (%u). "));
break;
default:
@@ -961,7 +961,7 @@ dissect_subobj_unnumb_interfaceID(proto_tree *pcep_subobj_tree, tvbuff_t *tvb, i
proto_tree_add_text(pcep_subobj_unnumb_interfaceID, tvb, offset, 1, "X: %x", (l_and_or_type & 0x01)>>7);
proto_tree_add_uint(pcep_subobj_unnumb_interfaceID, pcep_filter[PCEPF_SUBOBJ_XRO], tvb, offset, 1, (l_and_or_type & 0x7f));
proto_tree_add_text(pcep_subobj_unnumb_interfaceID, tvb, offset+2, 1, "Reserved: 0x%02x", (reserved_flags & 0xff00)>>4);
- proto_tree_add_text(pcep_subobj_unnumb_interfaceID, tvb, offset+3, 1, "%s", val_to_str((reserved_flags & 0x00ff), pcep_xro_atribute_obj_vals, "Unknown Atribute (%u). "));
+ proto_tree_add_text(pcep_subobj_unnumb_interfaceID, tvb, offset+3, 1, "%s", val_to_str((reserved_flags & 0x00ff), pcep_xro_attribute_obj_vals, "Unknown Attribute (%u). "));
break;
default:
@@ -1005,7 +1005,7 @@ dissect_subobj_autonomous_sys_num(proto_tree *pcep_subobj_tree, tvbuff_t *tvb, i
proto_tree_add_text(pcep_subobj_autonomous_sys_num, tvb, offset+1, 1, "Length: %u", length);
proto_tree_add_text(pcep_subobj_autonomous_sys_num, tvb, offset+2, 1, "Reserved: 0x%02x", reserved);
- proto_tree_add_text(pcep_subobj_autonomous_sys_num, tvb, offset+3, 1, "%s", val_to_str(attribute, pcep_xro_atribute_obj_vals, "Unknown Object (%u)."));
+ proto_tree_add_text(pcep_subobj_autonomous_sys_num, tvb, offset+3, 1, "%s", val_to_str(attribute, pcep_xro_attribute_obj_vals, "Unknown Object (%u)."));
proto_tree_add_text(pcep_subobj_autonomous_sys_num, tvb, offset+4, 2, "Optional AS Number High Octets: 0x%04x", AS_number);
proto_tree_add_text(pcep_subobj_autonomous_sys_num, tvb, offset+6, 2, "AS Number: 0x%04x", AS_number);
} else {
@@ -1058,7 +1058,7 @@ dissect_subobj_srlg(proto_tree *pcep_subobj_tree, tvbuff_t *tvb, int offset, gui
proto_tree_add_text(pcep_subobj_srlg, tvb, offset+2, 4, "SRLG ID: 0x%08x", srlg_id);
proto_tree_add_text(pcep_subobj_srlg, tvb, offset+6, 1, "Reserved: 0x%02x", reserved);
- proto_tree_add_text(pcep_subobj_srlg, tvb, offset+7, 1, "%s", val_to_str(attribute, pcep_xro_atribute_obj_vals, "Unknown Object (%u)."));
+ proto_tree_add_text(pcep_subobj_srlg, tvb, offset+7, 1, "%s", val_to_str(attribute, pcep_xro_attribute_obj_vals, "Unknown Object (%u)."));
}
static void
diff --git a/epan/dissectors/packet-pcnfsd.c b/epan/dissectors/packet-pcnfsd.c
index d1962ec9b6..5a6fd5fb32 100644
--- a/epan/dissectors/packet-pcnfsd.c
+++ b/epan/dissectors/packet-pcnfsd.c
@@ -373,13 +373,13 @@ proto_register_pcnfsd(void)
NULL, 0, "Authentication Client", HFILL }},
{ &hf_pcnfsd_auth_ident_obscure, {
"Obscure Ident", "pcnfsd.auth.ident.obscure", FT_STRING, BASE_DEC,
- NULL, 0, "Athentication Obscure Ident", HFILL }},
+ NULL, 0, "Authentication Obscure Ident", HFILL }},
{ &hf_pcnfsd_auth_ident_clear, {
"Clear Ident", "pcnfsd.auth.ident.clear", FT_STRING, BASE_DEC,
NULL, 0, "Authentication Clear Ident", HFILL }},
{ &hf_pcnfsd_auth_password_obscure, {
"Obscure Password", "pcnfsd.auth.password.obscure", FT_STRING, BASE_DEC,
- NULL, 0, "Athentication Obscure Password", HFILL }},
+ NULL, 0, "Authentication Obscure Password", HFILL }},
{ &hf_pcnfsd_auth_password_clear, {
"Clear Password", "pcnfsd.auth.password.clear", FT_STRING, BASE_DEC,
NULL, 0, "Authentication Clear Password", HFILL }},
diff --git a/epan/dissectors/packet-ppp.c b/epan/dissectors/packet-ppp.c
index bfa222eac2..eb5be8baa4 100644
--- a/epan/dissectors/packet-ppp.c
+++ b/epan/dissectors/packet-ppp.c
@@ -347,7 +347,7 @@ const value_string ppp_vals[] = {
{PPP_IPV6CP, "IPv6 Control Protocol" },
{PPP_MUXCP, "PPPMux Control Protocol"},
{PPP_STAMPEDECP,"Stampede Bridging Control Protocol" },
- {PPP_MPPCP, "MP+ Contorol Protocol" },
+ {PPP_MPPCP, "MP+ Control Protocol" },
{PPP_IPICP, "NTCITS IPI Control Protocol" },
{PPP_SLCC, "single link compression in multilink control" },
{PPP_CCP, "Compression Control Protocol" },
diff --git a/epan/dissectors/packet-ptp.c b/epan/dissectors/packet-ptp.c
index 8a99a75816..9e2337a93d 100644
--- a/epan/dissectors/packet-ptp.c
+++ b/epan/dissectors/packet-ptp.c
@@ -967,7 +967,7 @@ static const value_string ptp_v2_managementID_infocolumn_vals[] = {
{PTP_V2_MM_ID_PRIORITY2 ,"Priority 2"},
{PTP_V2_MM_ID_DOMAIN ,"Domain"},
{PTP_V2_MM_ID_SLAVE_ONLY ,"Slave only"},
- {PTP_V2_MM_ID_LOG_ANNOUNCE_INTERVAL ,"Log annonce interval"},
+ {PTP_V2_MM_ID_LOG_ANNOUNCE_INTERVAL ,"Log announce interval"},
{PTP_V2_MM_ID_ANNOUNCE_RECEIPT_TIMEOUT ,"Announce receipt timeout"},
{PTP_V2_MM_ID_LOG_SYNC_INTERVAL ,"Log sync interval"},
{PTP_V2_MM_ID_VERSION_NUMBER ,"Version number"},
diff --git a/epan/dissectors/packet-rdt.c b/epan/dissectors/packet-rdt.c
index 445a78bc85..b25fa6c289 100644
--- a/epan/dissectors/packet-rdt.c
+++ b/epan/dissectors/packet-rdt.c
@@ -218,7 +218,7 @@ static gboolean global_rdt_show_setup_info = TRUE;
static const value_string packet_type_vals[] =
{
{ RDT_ASMACTIION_PACKET, "Asm action" },
- { RDT_BANDWIDTHREPORT_PACKET, "Bandwith report" },
+ { RDT_BANDWIDTHREPORT_PACKET, "Bandwidth report" },
{ RDT_ACK_PACKET, "Ack" },
{ RDT_RTTREQUEST_PACKET, "RTT request" },
{ RDT_RTTRESPONSE_PACKET, "RTT response" },
diff --git a/epan/dissectors/packet-rtcp.c b/epan/dissectors/packet-rtcp.c
index c0120d31e0..5130c68262 100644
--- a/epan/dissectors/packet-rtcp.c
+++ b/epan/dissectors/packet-rtcp.c
@@ -3867,7 +3867,7 @@ proto_register_rtcp(void)
{
&hf_rtcp_xr_voip_metrics_plc,
{
- "Packet Loss Conealment Algorithm",
+ "Packet Loss Concealment Algorithm",
"rtcp.xr.voipmetrics.plc",
FT_UINT8,
BASE_DEC,
diff --git a/epan/dissectors/packet-s5066.c b/epan/dissectors/packet-s5066.c
index 44ab9e4b42..29406c0901 100644
--- a/epan/dissectors/packet-s5066.c
+++ b/epan/dissectors/packet-s5066.c
@@ -140,7 +140,7 @@ static gint hf_s5066_st_txmode = -1;
static const value_string s5066_st_txmode[] = {
{ 0, "Ignore service type field"},
{ 1, "ARQ"},
- { 2, "Non-ARQ (Broacast)"},
+ { 2, "Non-ARQ (Broadcast)"},
{ 3, "Non-ARQ (with errors)"},
{ 4, "Other non-ARQ types"},
{ 5, "Other non-ARQ types"},
diff --git a/epan/dissectors/packet-sccpmg.c b/epan/dissectors/packet-sccpmg.c
index 4a75b07bce..ae4de287c9 100644
--- a/epan/dissectors/packet-sccpmg.c
+++ b/epan/dissectors/packet-sccpmg.c
@@ -342,7 +342,7 @@ proto_register_sccpmg(void)
FT_UINT8, BASE_DEC, NULL, SCCPMG_SMI_MASK,
"", HFILL}},
{ &hf_sccpmg_congestion_level,
- { "SCCP Congestionl Level (ITU)", "sccpmg.congestion",
+ { "SCCP Congestion Level (ITU)", "sccpmg.congestion",
FT_UINT8, BASE_DEC, NULL, ITU_SCCPMG_CONGESTION_MASK,
"", HFILL}}
};
diff --git a/epan/dissectors/packet-scsi-mmc.c b/epan/dissectors/packet-scsi-mmc.c
index 2544512283..f9765fb5fb 100644
--- a/epan/dissectors/packet-scsi-mmc.c
+++ b/epan/dissectors/packet-scsi-mmc.c
@@ -525,8 +525,8 @@ static const value_string scsi_disc_info_disc_status_val[] = {
static const value_string scsi_disc_info_bgfs_val[] = {
{0x00, "Blank or not CD-RW/DVD-RW"},
{0x01, "Background Format started but is not running nor complete"},
- {0x02, "Backgroung Format in progress"},
- {0x03, "Backgroung Format has completed"},
+ {0x02, "Background Format in progress"},
+ {0x03, "Background Format has completed"},
{0,NULL}
};
diff --git a/epan/dissectors/packet-scsi.c b/epan/dissectors/packet-scsi.c
index f90f69f317..918b8dc96a 100644
--- a/epan/dissectors/packet-scsi.c
+++ b/epan/dissectors/packet-scsi.c
@@ -369,10 +369,10 @@ static const value_string scsi_spc_vals[] = {
static const value_string log_flags_tmc_vals[] = {
- {0, "Every update of the culmulative value"},
- {1, "Culmulative value equal to treshold value"},
- {2, "Culmulative value not equal to treshold value"},
- {3, "Culmulative value greater than treshold value"},
+ {0, "Every update of the cumulative value"},
+ {1, "Cumulative value equal to treshold value"},
+ {2, "Cumulative value not equal to treshold value"},
+ {3, "Cumulative value greater than treshold value"},
{0, NULL},
};
@@ -2071,8 +2071,8 @@ static const value_string inq_rdf_vals[] = {
#define SCSI_INQ_SCCSFLAGS_PROTECT 0x01
static const value_string inq_tpgs_vals[] = {
- { 0, "Assymetric LU Access not supported" },
- { 1, "Implicit Assymetric LU Access supported" },
+ { 0, "Asymmetric LU Access not supported" },
+ { 1, "Implicit Asymmetric LU Access supported" },
{ 2, "Explicit LU Access supported" },
{ 3, "Both Implicit and Explicit LU Access supported" },
{ 0, NULL }
diff --git a/epan/dissectors/packet-smb.c b/epan/dissectors/packet-smb.c
index 9f034c5b9f..1fb96eab91 100644
--- a/epan/dissectors/packet-smb.c
+++ b/epan/dissectors/packet-smb.c
@@ -18096,7 +18096,7 @@ proto_register_smb(void)
{ &hf_smb_nt_create_options_sequential_only,
{ "Sequential Only", "smb.nt.create_options.sequential_only", FT_BOOLEAN, 32,
- TFS(&tfs_nt_create_options_sequential_only), 0x00000004, "Will accees to thsis file only be sequential?", HFILL }},
+ TFS(&tfs_nt_create_options_sequential_only), 0x00000004, "Will access to thsis file only be sequential?", HFILL }},
{ &hf_smb_nt_create_options_no_intermediate_buffering,
{ "Intermediate Buffering", "smb.nt.create_options.intermediate_buffering", FT_BOOLEAN, 32,
diff --git a/epan/dissectors/packet-smpp.c b/epan/dissectors/packet-smpp.c
index 9188c6e99d..31c32e032c 100644
--- a/epan/dissectors/packet-smpp.c
+++ b/epan/dissectors/packet-smpp.c
@@ -2502,7 +2502,7 @@ proto_register_smpp(void)
{ &hf_smpp_system_type,
{ "System type", "smpp.system_type",
FT_STRING, BASE_NONE, NULL, 0x00,
- "Categorises the system.",
+ "Categorizes the system.",
HFILL
}
},
diff --git a/epan/dissectors/packet-sna.c b/epan/dissectors/packet-sna.c
index 003c7c7070..978bb0fc24 100644
--- a/epan/dissectors/packet-sna.c
+++ b/epan/dissectors/packet-sna.c
@@ -315,7 +315,7 @@ static const value_string sna_th_fid_vals[] = {
{ 0xb, "HPR NLP Frame Routing" },
{ 0xc, "HPR NLP Automatic Network Routing" },
{ 0xd, "HPR NLP Automatic Network Routing" },
- { 0xf, "Adjaced Subarea Nodes, supporting ER and VR" },
+ { 0xf, "Adjacent Subarea Nodes, supporting ER and VR" },
{ 0x0, NULL }
};
diff --git a/epan/dissectors/packet-ssl.c b/epan/dissectors/packet-ssl.c
index 5e86372a02..2a0c5fb491 100644
--- a/epan/dissectors/packet-ssl.c
+++ b/epan/dissectors/packet-ssl.c
@@ -605,7 +605,7 @@ dissect_ssl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
conv_version =& ssl_session->version;
/* try decryption only the first time we see this packet
- * (to keep cipher syncronized) and only if we have
+ * (to keep cipher synchronized) and only if we have
* the server private key*/
if (pinfo->fd->flags.visited)
ssl_session = NULL;
@@ -2942,7 +2942,7 @@ dissect_pct_msg_client_hello(tvbuff_t *tvb,
proto_tree_add_text(tree, tvb, offset, 32, "Client Session ID Data (32 bytes)");
offset += 32;
- proto_tree_add_text(tree, tvb, offset, 32, "Challange Data(32 bytes)");
+ proto_tree_add_text(tree, tvb, offset, 32, "Challenge Data(32 bytes)");
offset += 32;
CH_OFFSET = tvb_get_ntohs(tvb, offset);
diff --git a/epan/dissectors/packet-tcp.c b/epan/dissectors/packet-tcp.c
index 3d6c365958..9cea1e3671 100644
--- a/epan/dissectors/packet-tcp.c
+++ b/epan/dissectors/packet-tcp.c
@@ -1418,7 +1418,7 @@ tcp_print_sequence_number_analysis(packet_info *pinfo, tvbuff_t *tvb, proto_tree
#define TCPOPT_CCNEW 12
#define TCPOPT_CCECHO 13
#define TCPOPT_MD5 19 /* RFC2385 */
-#define TCPOPT_SCPS 20 /* SCPS Capabilties */
+#define TCPOPT_SCPS 20 /* SCPS Capabilities */
#define TCPOPT_SNACK 21 /* SCPS SNACK */
#define TCPOPT_RECBOUND 22 /* SCPS Record Boundary */
#define TCPOPT_CORREXP 23 /* SCPS Corruption Experienced */
@@ -2652,7 +2652,7 @@ static const ip_tcp_opt tcpopts[] = {
},
{
TCPOPT_SCPS,
- "SCPS capabilties",
+ "SCPS capabilities",
&ett_tcp_option_scps,
VARIABLE_LENGTH,
TCPOLEN_SCPS,
diff --git a/epan/dissectors/packet-ucp.c b/epan/dissectors/packet-ucp.c
index 927886230d..9b9f905719 100644
--- a/epan/dissectors/packet-ucp.c
+++ b/epan/dissectors/packet-ucp.c
@@ -311,7 +311,7 @@ static const value_string vals_parm_EC[] = { /* Error code */
{ 13, "Legitimisation code for priority call, failure" },
{ 14, "Urgent message not allowed" },
{ 15, "Legitimisation code for urgent message, failure" },
- { 16, "Reverse charging not alllowed" },
+ { 16, "Reverse charging not allowed" },
{ 17, "Legitimisation code for rev. charging, failure" },
{ 18, "Deferred delivery not allowed" },
{ 19, "New AC not valid" },
diff --git a/epan/dissectors/packet-umts_fp.c b/epan/dissectors/packet-umts_fp.c
index 56748aeecf..932b6674a1 100644
--- a/epan/dissectors/packet-umts_fp.c
+++ b/epan/dissectors/packet-umts_fp.c
@@ -350,10 +350,10 @@ static int dissect_common_dl_node_synchronisation(packet_info *pinfo, proto_tree
tvbuff_t *tvb, int offset);
static int dissect_common_ul_node_synchronisation(packet_info *pinfo, proto_tree *tree,
tvbuff_t *tvb, int offset);
-static int dissect_common_dl_syncronisation(packet_info *pinfo, proto_tree *tree,
+static int dissect_common_dl_synchronisation(packet_info *pinfo, proto_tree *tree,
tvbuff_t *tvb, int offset,
struct fp_info *p_fp_info);
-static int dissect_common_ul_syncronisation(packet_info *pinfo, proto_tree *tree,
+static int dissect_common_ul_synchronisation(packet_info *pinfo, proto_tree *tree,
tvbuff_t *tvb, int offset,
struct fp_info *p_fp_info);
static int dissect_common_timing_advance(packet_info *pinfo, proto_tree *tree,
@@ -820,7 +820,7 @@ int dissect_common_ul_node_synchronisation(packet_info *pinfo, proto_tree *tree,
return offset;
}
-int dissect_common_dl_syncronisation(packet_info *pinfo, proto_tree *tree,
+int dissect_common_dl_synchronisation(packet_info *pinfo, proto_tree *tree,
tvbuff_t *tvb, int offset, struct fp_info *p_fp_info)
{
guint16 cfn;
@@ -850,7 +850,7 @@ int dissect_common_dl_syncronisation(packet_info *pinfo, proto_tree *tree,
return offset;
}
-int dissect_common_ul_syncronisation(packet_info *pinfo, proto_tree *tree,
+int dissect_common_ul_synchronisation(packet_info *pinfo, proto_tree *tree,
tvbuff_t *tvb, int offset, struct fp_info *p_fp_info)
{
return dissect_common_timing_adjustment(pinfo, tree, tvb, offset, p_fp_info);
@@ -1146,10 +1146,10 @@ void dissect_common_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
offset = dissect_common_timing_adjustment(pinfo, tree, tvb, offset, p_fp_info);
break;
case COMMON_DL_SYNCHRONISATION:
- offset = dissect_common_dl_syncronisation(pinfo, tree, tvb, offset, p_fp_info);
+ offset = dissect_common_dl_synchronisation(pinfo, tree, tvb, offset, p_fp_info);
break;
case COMMON_UL_SYNCHRONISATION:
- offset = dissect_common_ul_syncronisation(pinfo, tree, tvb, offset, p_fp_info);
+ offset = dissect_common_ul_synchronisation(pinfo, tree, tvb, offset, p_fp_info);
break;
case COMMON_DL_NODE_SYNCHRONISATION:
offset = dissect_common_dl_node_synchronisation(pinfo, tree, tvb, offset);
diff --git a/epan/dissectors/packet-user_encap.c b/epan/dissectors/packet-user_encap.c
index 61d338257c..7979c46fe3 100644
--- a/epan/dissectors/packet-user_encap.c
+++ b/epan/dissectors/packet-user_encap.c
@@ -185,7 +185,7 @@ void proto_register_user_encap(void)
prefs_register_uat_preference(module,
"encaps_table",
"Encapsulations Table",
- "A table that enumerates the various protocols to be used against a cartain user DLT",
+ "A table that enumerates the various protocols to be used against a certain user DLT",
encaps_uat);
diff --git a/epan/dissectors/packet-wps.c b/epan/dissectors/packet-wps.c
index 5bcfb930e8..ab25913715 100644
--- a/epan/dissectors/packet-wps.c
+++ b/epan/dissectors/packet-wps.c
@@ -1376,7 +1376,7 @@ dissect_exteap_wps(proto_tree *eap_tree, tvbuff_t *tvb, int offset,
pi = proto_item_get_parent(pi);
if (pi != NULL)
- proto_item_append_text(pi, " (Wifi Allicance, WifiProtectedSetup)");
+ proto_item_append_text(pi, " (Wifi Alliance, WifiProtectedSetup)");
if (pinfo != NULL && check_col(pinfo->cinfo, COL_INFO))
col_append_fstr(pinfo->cinfo, COL_INFO, ", WPS");
diff --git a/epan/dissectors/packet-xtp.c b/epan/dissectors/packet-xtp.c
index 548de6ec45..f6d8c24b01 100644
--- a/epan/dissectors/packet-xtp.c
+++ b/epan/dissectors/packet-xtp.c
@@ -84,7 +84,7 @@ static const value_string pformat_vals[] = {
static const value_string diag_code_vals[] = {
{ 1, "Context Refused" },
- { 2, "Context Abaondoned" },
+ { 2, "Context Abandoned" },
{ 3, "Invalid Context" },
{ 4, "Request Refused" },
{ 5, "Join Refused" },
diff --git a/epan/dissectors/packet-dcm.c b/epan/dissectors/packet-dcm.c
index 76017f83ae..d8bc659681 100644
--- a/epan/dissectors/packet-dcm.c
+++ b/epan/dissectors/packet-dcm.c
@@ -109,8 +109,8 @@
* - Fixed PDV Continuation. Last packet was not found correctly.
* - Fixed complilation warning (build 56 on solaris)
* - Fixed tree expansion (hf_dcm_xxx)
* - Added expert_add_info() for Assoctiation Reject
* - Added expert_add_info() for Assoctiation Abort
* - Added expert_add_info() for short PDVs (i.e. last fragment, but PDV is not completed yet)
* - Clarified and grouped data structures and its related code (dcmItem, dcmState) to have
* consistent _new() & _get() functions and to be be according to coding conventions
@@ -6419,10 +6419,10 @@ dissect_dcm_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 off
proto_tree_add_item(dcm_tree, hf_dcm_pdu_len, tvb, offset+2, 4, FALSE);
if (pdu_type==3) {
- expert_add_info_format(pinfo, ti_pdu_type, PI_RESPONSE_CODE, PI_WARN, "Asscociation rejected");
+ expert_add_info_format(pinfo, ti_pdu_type, PI_RESPONSE_CODE, PI_WARN, "Association rejected");
}
else if (pdu_type==7) {
- expert_add_info_format(pinfo, ti_pdu_type, PI_RESPONSE_CODE, PI_WARN, "Asscociation aborted");
+ expert_add_info_format(pinfo, ti_pdu_type, PI_RESPONSE_CODE, PI_WARN, "Association aborted");
}
switch (pdu_type) {
@@ -6618,7 +6618,7 @@ proto_register_dcm(void)
prefs_register_bool_preference(dcm_module, "export_header",
"Create Meta Header on Export",
"Create DICOM File Meta Header according to PS 3.10 on export for PDUs. "
- "If the cpatured PDV does not contain a SOP Class UID and SOP Instance UID "
+ "If the captured PDV does not contain a SOP Class UID and SOP Instance UID "
"(e.g. for command PDVs), wireshark spefic ones will be created.",
&global_dcm_export_header);
@@ -109,8 +109,8 @@
* - Fixed complilation warning (build 56 on solaris)
* - Fixed tree expansion (hf_dcm_xxx)
- * - Added expert_add_info() for Assoctiation Reject
- * - Added expert_add_info() for Assoctiation Abort
+ * - Added expert_add_info() for Association Reject
+ * - Added expert_add_info() for Association Abort
* - Added expert_add_info() for short PDVs (i.e. last fragment, but PDV is not completed yet)
* - Clarified and grouped data structures and its related code (dcmItem, dcmState) to have
diff --git a/epan/dissectors/packet-isup.c b/epan/dissectors/packet-isup.c
index bbf2bb3c00..90b6c438cb 100644
--- a/epan/dissectors/packet-isup.c
+++ b/epan/dissectors/packet-isup.c
@@ -520,7 +520,7 @@ static const value_string ansi_isup_parameter_type_value[] = {
{ ANSI_ISUP_PARAM_TYPE_EGRESS, "Egress"},
{ ANSI_ISUP_PARAM_TYPE_JURISDICTION, "Jurisdiction"},
{ ANSI_ISUP_PARAM_TYPE_CARRIER_ID, "Carrier identification"},
- { ANSI_ISUP_PARAM_TYPE_BUSINESS_GRP, "Buisiness group"},
+ { ANSI_ISUP_PARAM_TYPE_BUSINESS_GRP, "Business group"},
{ ANSI_ISUP_PARAM_TYPE_GENERIC_NAME, "Generic name"},
{ ANSI_ISUP_PARAM_TYPE_NOTIF_IND, "Notification indicator"},
{ ANSI_ISUP_PARAM_TYPE_CG_CHAR_IND, "Circuit group characteristic indicator"},
@@ -1303,7 +1303,7 @@ static const value_string isup_auto_congestion_level_value[] = {
static const true_false_string isup_inband_information_ind_value = {
/* according 3.37/Q.763 */
- "in-band information or an appropirate pattern is now available",
+ "in-band information or an appropriate pattern is now available",
"no indication"
};
static const true_false_string isup_call_diversion_may_occur_ind_value = {
@@ -1813,7 +1813,7 @@ dissect_isup_circuit_group_char_ind_parameter(tvbuff_t *parameter_tvb, proto_tre
proto_tree_add_uint(parameter_tree, hf_isup_cvr_cg_alarm_car_ind, parameter_tvb, 0, CG_CHAR_IND_LENGTH, cvr_cg_char_ind );
proto_tree_add_uint(parameter_tree, hf_isup_cvr_cont_chk_ind, parameter_tvb, 0, CG_CHAR_IND_LENGTH, cvr_cg_char_ind );
- proto_item_set_text(parameter_item, "Circuit Validation Test Response Circuit Group Characterstics: 0x%x", cvr_cg_char_ind );
+ proto_item_set_text(parameter_item, "Circuit Validation Test Response Circuit Group Characteristics: 0x%x", cvr_cg_char_ind );
}
/* ------------------------------------------------------------------
@@ -3077,7 +3077,7 @@ dissect_bat_ase_Encapsulated_Application_Information(tvbuff_t *parameter_tvb, pa
bat_ase_element_tree = proto_item_add_subtree(bat_ase_element_item ,
ett_bat_ase_element);
if ( identifier != CODEC ) {
- /* identifier, lengt indicator and compabillity info must be printed inside CODEC */
+ /* identifier, length indicator and compabillity info must be printed inside CODEC */
/* dissection in order to use dissect_codec routine for codec list */
proto_tree_add_uint(bat_ase_element_tree , hf_bat_ase_identifier , parameter_tvb,
offset - length_ind_len, 1, identifier );
@@ -5775,11 +5775,11 @@ dissect_ansi_isup_circuit_validation_test_resp_message(tvbuff_t *message_tvb, pr
dissect_isup_cvr_response_ind_parameter(parameter_tvb, parameter_tree, parameter_item);
offset += CVR_RESP_IND_LENGTH;
/* Do stuff for second mandatory fixed parameter: CG Characterstics Indicator */
parameter_type = ANSI_ISUP_PARAM_TYPE_CG_CHAR_IND;
parameter_item = proto_tree_add_text(isup_tree, message_tvb, offset,
CG_CHAR_IND_LENGTH,
- "Circuit Group Characterstics Indicators");
+ "Circuit Group Characteristics Indicators");
parameter_tree = proto_item_add_subtree(parameter_item, ett_isup_parameter);
proto_tree_add_uint_format(parameter_tree, hf_isup_parameter_type, message_tvb, 0, 0, parameter_type, "Mandatory Parameter: %u (%s)", parameter_type, val_to_str(parameter_type, isup_parameter_type_value,"Circuit Group Characters"));
actual_length = tvb_ensure_length_remaining(message_tvb, offset);
@@ -7959,7 +7959,7 @@ proto_register_isup(void)
"", HFILL }},
{ &hf_BAT_ASE_Comp_Report_Reason,
- { "Compabillity report reason", "bat_ase.Comp_Report_Reason",
+ { "Compatibility report reason", "bat_ase.Comp_Report_Reason",
FT_UINT8, BASE_HEX, VALS(BAT_ASE_Report_Reason_vals),0x0,
"", HFILL }},
@@ -5775,11 +5775,11 @@ dissect_ansi_isup_circuit_validation_test_resp_message(tvbuff_t *message_tvb, pr
dissect_isup_cvr_response_ind_parameter(parameter_tvb, parameter_tree, parameter_item);
offset += CVR_RESP_IND_LENGTH;
- /* Do stuff for second mandatory fixed parameter: CG Characterstics Indicator */
+ /* Do stuff for second mandatory fixed parameter: CG Characteristics Indicator */
parameter_type = ANSI_ISUP_PARAM_TYPE_CG_CHAR_IND;
parameter_item = proto_tree_add_text(isup_tree, message_tvb, offset,